@@ -60,8 +60,6 @@ oa2df <- function(data, entity, options = NULL, count_only = FALSE, group_by = N
   }
 
   if (entity != "snowball"){
-    # replace NULL with NA
-    data <- simple_rapply(data, `%||%`, y = NA)
     ch <- ifelse(is.null(options$select), "id", options$select[[1]])
     if (!is.null(data[[ch]])) {
       data <- list(data)
@@ -89,6 +87,8 @@ oa2df <- function(data, entity, options = NULL, count_only = FALSE, group_by = N
 #'
 #' @param abstract Logical. If TRUE, the function returns also the abstract of each item.
 #' Defaults to TRUE.
+#' @param pb Progress bar object. If verbose, computed from `oa_progress`.
+#' NULL otherwise.
 #' @inheritParams oa2df
 #'
 #' @return a data.frame.
@@ -133,7 +133,8 @@ oa2df <- function(data, entity, options = NULL, count_only = FALSE, group_by = N
 #'
 #' @export
 #'
-works2df <- function(data, abstract = TRUE, verbose = TRUE) {
+works2df <- function(data, abstract = TRUE, verbose = TRUE,
+                     pb = if (verbose) oa_progress(length(data)) else NULL) {
 
   col_order <- c(
     "id", "display_name", "author", "ab", "publication_date", "relevance_score",
@@ -183,14 +184,12 @@ works2df <- function(data, abstract = TRUE, verbose = TRUE) {
   empty_inst <- empty_list(inst_cols)
 
   n <- length(data)
-  pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
 
   for (i in seq.int(n)) {
     if (verbose) pb$tick()
 
     paper <- data[[i]]
-    paper <- simple_rapply(paper, `%||%`, y = NA)
 
     fields <- works_process[works_process$field %in% names(paper), ]
     sim_fields <- mapply(
@@ -274,7 +273,7 @@ abstract_build <- function(ab) {
 #' It converts bibliographic collection of authors' records gathered from OpenAlex database \href{https://openalex.org/}{https://openalex.org/} into data frame.
 #' The function converts a list of authors' records obtained using \code{oa_request} into a data frame/tibble.
 #'
-#' @inheritParams oa2df
+#' @inheritParams works2df
 #'
 #' @return a data.frame.
 #'
@@ -309,10 +308,9 @@ abstract_build <- function(ab) {
 #' }
 #'
 #' @export
-authors2df <- function(data, verbose = TRUE) {
-
+authors2df <- function(data, verbose = TRUE,
+                       pb = if (verbose) oa_progress(length(data)) else NULL) {
   n <- length(data)
-  pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
 
   inst_cols <- c("id", "display_name", "ror", "country_code", "type", "lineage")
@@ -379,7 +377,7 @@ authors2df <- function(data, verbose = TRUE) {
 #' It converts bibliographic collection of institutions' records gathered from OpenAlex database \href{https://openalex.org/}{https://openalex.org/} into data frame.
 #' The function converts a list of institutions' records obtained using \code{oa_request} into a data frame/tibble.
 #'
-#' @inheritParams oa2df
+#' @inheritParams works2df
 #'
 #' @return a data.frame.
 #'
@@ -407,10 +405,9 @@ authors2df <- function(data, verbose = TRUE) {
 #' }
 #'
 #' @export
-institutions2df <- function(data, verbose = TRUE) {
-
+institutions2df <- function(data, verbose = TRUE,
+                            pb = if (verbose) oa_progress(length(data)) else NULL) {
   n <- length(data)
-  pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
 
   institution_process <- tibble::tribble(
@@ -481,7 +478,7 @@ institutions2df <- function(data, verbose = TRUE) {
 #' It converts bibliographic collection of venues' records gathered from OpenAlex database \href{https://openalex.org/}{https://openalex.org/} into data frame.
 #' The function converts a list of venues' records obtained using \code{oa_request} into a data frame/tibble.
 #'
-#' @inheritParams oa2df
+#' @inheritParams works2df
 #'
 #' @return a data.frame.
 #'
@@ -511,10 +508,10 @@ institutions2df <- function(data, verbose = TRUE) {
 #' }
 #'
 #' @export
-venues2df <- function(data, verbose = TRUE) {
+venues2df <- function(data, verbose = TRUE,
+                      pb = if (verbose) oa_progress(length(data)) else NULL) {
 
   n <- length(data)
-  pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
   venue_process <- tibble::tribble(
     ~type, ~field,
@@ -567,7 +564,7 @@ venues2df <- function(data, verbose = TRUE) {
 #' It converts bibliographic collection of concepts' records gathered from OpenAlex database \href{https://openalex.org/}{https://openalex.org/} into data frame.
 #' The function converts a list of concepts' records obtained using \code{oa_request} into a data frame/tibble.
 #'
-#' @inheritParams oa2df
+#' @inheritParams works2df
 #'
 #' @return a data.frame.
 #'
@@ -597,7 +594,8 @@ venues2df <- function(data, verbose = TRUE) {
 #' }
 #'
 #' @export
-concepts2df <- function(data, verbose = TRUE) {
+concepts2df <- function(data, verbose = TRUE,
+                        pb = if (verbose) oa_progress(length(data)) else NULL) {
 
   concept_process <- tibble::tribble(
     ~type, ~field,
@@ -619,7 +617,6 @@ concepts2df <- function(data, verbose = TRUE) {
   )
 
   n <- length(data)
-  pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
 
   for (i in seq.int(n)) {
@@ -666,7 +663,7 @@ concepts2df <- function(data, verbose = TRUE) {
 #' It converts bibliographic collection of funders' records gathered from OpenAlex database \href{https://openalex.org/}{https://openalex.org/} into data frame.
 #' The function converts a list of funders' records obtained using \code{oa_request} into a data frame/tibble.
 #'
-#' @inheritParams oa2df
+#' @inheritParams works2df
 #'
 #' @return a data.frame.
 #'
@@ -688,7 +685,8 @@ concepts2df <- function(data, verbose = TRUE) {
 #' }
 #'
 #' @export
-funders2df <- function(data, verbose = TRUE) {
+funders2df <- function(data, verbose = TRUE,
+                       pb = if (verbose) oa_progress(length(data)) else NULL) {
 
   funder_process <- tibble::tribble(
     ~type, ~field,
@@ -712,7 +710,6 @@ funders2df <- function(data, verbose = TRUE) {
   )
 
   n <- length(data)
-  pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
 
   for (i in seq.int(n)) {
@@ -740,7 +737,7 @@ funders2df <- function(data, verbose = TRUE) {
 #' It converts bibliographic collection of sources' records gathered from OpenAlex database \href{https://openalex.org/}{https://openalex.org/} into data frame.
 #' The function converts a list of sources' records obtained using \code{oa_request} into a data frame/tibble.
 #'
-#' @inheritParams oa2df
+#' @inheritParams works2df
 #'
 #' @return a data.frame.
 #'
@@ -762,7 +759,8 @@ funders2df <- function(data, verbose = TRUE) {
 #' }
 #'
 #' @export
-sources2df <- function(data, verbose = TRUE) {
+sources2df <- function(data, verbose = TRUE,
+                       pb = if (verbose) oa_progress(length(data)) else NULL) {
 
   source_process <- tibble::tribble(
     ~type, ~field,
@@ -796,7 +794,6 @@ sources2df <- function(data, verbose = TRUE) {
   )
 
   n <- length(data)
-  pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
 
   for (i in seq.int(n)) {
@@ -824,7 +821,7 @@ sources2df <- function(data, verbose = TRUE) {
 #' It converts bibliographic collection of publishers' records gathered from OpenAlex database \href{https://openalex.org/}{https://openalex.org/} into data frame.
 #' The function converts a list of publishers' records obtained using \code{oa_request} into a data frame/tibble.
 #'
-#' @inheritParams oa2df
+#' @inheritParams works2df
 #'
 #' @return a data.frame.
 #'
@@ -846,7 +843,8 @@ sources2df <- function(data, verbose = TRUE) {
 #' }
 #'
 #' @export
-publishers2df <- function(data, verbose = TRUE) {
+publishers2df <- function(data, verbose = TRUE,
+                          pb = if (verbose) oa_progress(length(data)) else NULL) {
 
   publisher_process <- tibble::tribble(
     ~type, ~field,
@@ -872,7 +870,6 @@ publishers2df <- function(data, verbose = TRUE) {
   )
 
   n <- length(data)
-  pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
 
   for (i in seq.int(n)) {
